@@ -1,24 +1,22 @@
+import os
 import warnings
 from datetime import datetime as dt
 from pathlib import Path
-import os
 
 import fsspec
-from fsspec.implementations.local import LocalFileSystem
 import zarr
+from fsspec.implementations.local import LocalFileSystem
 
+from ..echodata.echodata import XARRAY_ENGINE_MAP, EchoData
 from ..utils import io
-
-from ..echodata.echodata import EchoData, XARRAY_ENGINE_MAP
-
+from .parse_ad2cp import ParseAd2cp
 from .parse_azfp import ParseAZFP
 from .parse_ek60 import ParseEK60
 from .parse_ek80 import ParseEK80
-from .parse_ad2cp import ParseAd2cp
+from .set_groups_ad2cp import SetGroupsAd2cp
 from .set_groups_azfp import SetGroupsAZFP
 from .set_groups_ek60 import SetGroupsEK60
 from .set_groups_ek80 import SetGroupsEK80
-from .set_groups_ad2cp import SetGroupsAd2cp
 
 MODELS = {
     "AZFP": {
@@ -27,18 +25,38 @@ MODELS = {
         "parser": ParseAZFP,
         "set_groups": SetGroupsAZFP,
     },
-    "EK60": {"ext": ".raw", "xml": False, "parser": ParseEK60, "set_groups": SetGroupsEK60},
-    "EK80": {"ext": ".raw", "xml": False, "parser": ParseEK80, "set_groups": SetGroupsEK80},
-    "EA640": {"ext": ".raw", "xml": False, "parser": ParseEK80, "set_groups": SetGroupsEK80},
-    "AD2CP": {"ext": ".ad2cp", "xml": False, "parser": ParseAd2cp, "set_groups": SetGroupsAd2cp},
+    "EK60": {
+        "ext": ".raw",
+        "xml": False,
+        "parser": ParseEK60,
+        "set_groups": SetGroupsEK60,
+    },
+    "EK80": {
+        "ext": ".raw",
+        "xml": False,
+        "parser": ParseEK80,
+        "set_groups": SetGroupsEK80,
+    },
+    "EA640": {
+        "ext": ".raw",
+        "xml": False,
+        "parser": ParseEK80,
+        "set_groups": SetGroupsEK80,
+    },
+    "AD2CP": {
+        "ext": ".ad2cp",
+        "xml": False,
+        "parser": ParseAd2cp,
+        "set_groups": SetGroupsAd2cp,
+    },
 }
 
 COMPRESSION_SETTINGS = {
-    'netcdf4': {'zlib': True, 'complevel': 4},
-    'zarr': {'compressor': zarr.Blosc(cname='zstd', clevel=3, shuffle=2)},
+    "netcdf4": {"zlib": True, "complevel": 4},
+    "zarr": {"compressor": zarr.Blosc(cname="zstd", clevel=3, shuffle=2)},
 }
 
-DEFAULT_CHUNK_SIZE = {'range_bin': 25000, 'ping_time': 2500}
+DEFAULT_CHUNK_SIZE = {"range_bin": 25000, "ping_time": 2500}
 
 NMEA_SENTENCE_DEFAULT = ["GGA", "GLL", "RMC"]
 
@@ -50,9 +68,7 @@ def _normalize_path(out_f, convert_type, output_storage_options):
         return out_f
 
 
-def _validate_path(
-    source_file, file_format, output_storage_options={}, save_path=None
-):
+def _validate_path(source_file, file_format, output_storage_options={}, save_path=None):
     """Assemble output file names and path.
 
     Parameters
@@ -79,7 +95,7 @@ def _validate_path(
 
     else:
         if not isinstance(save_path, Path) and not isinstance(save_path, str):
-            raise TypeError('save_path must be a string or Path')
+            raise TypeError("save_path must be a string or Path")
 
         fsmap = fsspec.get_mapper(str(save_path), **output_storage_options)
         output_fs = fsmap.fs
@@ -145,9 +161,7 @@ def to_file(
         Additional keywords to pass to the filesystem class.
     """
     if parallel:
-        raise NotImplementedError(
-            "Parallel conversion is not yet implemented."
-        )
+        raise NotImplementedError("Parallel conversion is not yet implemented.")
     if engine not in XARRAY_ENGINE_MAP.values():
         raise ValueError("Unknown type to convert file to!")
 
@@ -161,15 +175,13 @@ def to_file(
     )
 
     # Get all existing files
-    fs = fsspec.get_mapper(
-        output_file, **output_storage_options
-    ).fs  # get file system
+    fs = fsspec.get_mapper(output_file, **output_storage_options).fs  # get file system
     exists = True if fs.exists(output_file) else False
 
     # Sequential or parallel conversion
     if exists and not overwrite:
         print(
-            f"{dt.now().strftime('%H:%M:%S')}  {echodata.source_file} has already been converted to {engine}. "
+            f"{dt.now().strftime('%H:%M:%S')}  {echodata.source_file} has already been converted to {engine}. "  # noqa
             f"File saving not executed."
         )
     else:
@@ -179,9 +191,7 @@ def to_file(
             print(f"{dt.now().strftime('%H:%M:%S')}  saving {output_file}")
         _save_groups_to_file(
             echodata,
-            output_path=_normalize_path(
-                output_file, engine, output_storage_options
-            ),
+            output_path=_normalize_path(output_file, engine, output_storage_options),
             engine=engine,
             compress=compress,
         )
@@ -195,34 +205,34 @@ def _save_groups_to_file(echodata, output_path, engine, compress=True):
     # TODO: in terms of chunking, would using rechunker at the end be faster and more convenient?
 
     # Top-level group
-    io.save_file(echodata.top, path=output_path, mode='w', engine=engine)
+    io.save_file(echodata.top, path=output_path, mode="w", engine=engine)
 
     # Provenance group
     io.save_file(
         echodata.provenance,
         path=output_path,
-        group='Provenance',
-        mode='a',
+        group="Provenance",
+        mode="a",
         engine=engine,
     )
 
     # Environment group
     io.save_file(
         echodata.environment.chunk(
-            {'ping_time': DEFAULT_CHUNK_SIZE['ping_time']}
+            {"ping_time": DEFAULT_CHUNK_SIZE["ping_time"]}
         ),  # TODO: chunking necessary?
         path=output_path,
-        mode='a',
+        mode="a",
         engine=engine,
-        group='Environment',
+        group="Environment",
     )
 
     # Sonar group
     io.save_file(
         echodata.sonar,
         path=output_path,
-        group='Sonar',
-        mode='a',
+        group="Sonar",
+        mode="a",
         engine=engine,
     )
 
@@ -231,48 +241,42 @@ def _save_groups_to_file(echodata, output_path, engine, compress=True):
         io.save_file(
             echodata.beam.chunk(
                 {
-                    'ping_time': DEFAULT_CHUNK_SIZE['ping_time'],
+                    "ping_time": DEFAULT_CHUNK_SIZE["ping_time"],
                 }
             ),
             path=output_path,
-            mode='a',
+            mode="a",
             engine=engine,
-            group='Beam',
-            compression_settings=COMPRESSION_SETTINGS[engine]
-            if compress
-            else None,
+            group="Beam",
+            compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
         )
     else:
         io.save_file(
             echodata.beam.chunk(
                 {
-                    'range_bin': DEFAULT_CHUNK_SIZE['range_bin'],
-                    'ping_time': DEFAULT_CHUNK_SIZE['ping_time'],
+                    "range_bin": DEFAULT_CHUNK_SIZE["range_bin"],
+                    "ping_time": DEFAULT_CHUNK_SIZE["ping_time"],
                 }
             ),
             path=output_path,
-            mode='a',
+            mode="a",
             engine=engine,
-            group='Beam',
-            compression_settings=COMPRESSION_SETTINGS[engine]
-            if compress
-            else None,
+            group="Beam",
+            compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
         )
     if echodata.beam_power is not None:
         io.save_file(
             echodata.beam_power.chunk(
                 {
-                    'range_bin': DEFAULT_CHUNK_SIZE['range_bin'],
-                    'ping_time': DEFAULT_CHUNK_SIZE['ping_time'],
+                    "range_bin": DEFAULT_CHUNK_SIZE["range_bin"],
+                    "ping_time": DEFAULT_CHUNK_SIZE["ping_time"],
                 }
             ),
             path=output_path,
-            mode='a',
+            mode="a",
             engine=engine,
-            group='Beam_power',
-            compression_settings=COMPRESSION_SETTINGS[engine]
-            if compress
-            else None,
+            group="Beam_power",
+            compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
         )
 
     # Beam Complex Group: only AD2CP has Beam Complex
@@ -280,63 +284,53 @@ def _save_groups_to_file(echodata, output_path, engine, compress=True):
         io.save_file(
             echodata.beam_complex,
             path=output_path,
-            mode='a',
+            mode="a",
             engine=engine,
-            group='Beam',
-            compression_settings=COMPRESSION_SETTINGS[engine]
-            if compress
-            else None,
+            group="Beam_complex",
+            compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
         )
 
     # Platform group
     io.save_file(
         echodata.platform,  # TODO: chunking necessary? location_time and mru_time (EK80) only
         path=output_path,
-        mode='a',
+        mode="a",
         engine=engine,
-        group='Platform',
-        compression_settings=COMPRESSION_SETTINGS[engine]
-        if compress
-        else None,
+        group="Platform",
+        compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
     )
 
     # Platform/NMEA group: some sonar model does not produce NMEA data
-    if hasattr(echodata, 'nmea'):
+    if hasattr(echodata, "nmea"):
         io.save_file(
             echodata.nmea,  # TODO: chunking necessary?
             path=output_path,
-            mode='a',
+            mode="a",
             engine=engine,
-            group='Platform/NMEA',
-            compression_settings=COMPRESSION_SETTINGS[engine]
-            if compress
-            else None,
+            group="Platform/NMEA",
+            compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
         )
 
     # Vendor-specific group
     if "ping_time" in echodata.vendor:
         io.save_file(
             echodata.vendor.chunk(
-                {'ping_time': DEFAULT_CHUNK_SIZE['ping_time']}
+                {"ping_time": DEFAULT_CHUNK_SIZE["ping_time"]}
             ),  # TODO: chunking necessary?
             path=output_path,
-            mode='a',
+            mode="a",
             engine=engine,
-            group='Vendor',
-            compression_settings=COMPRESSION_SETTINGS[engine]
-            if compress
-            else None,
+            group="Vendor",
+            compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
         )
     else:
         io.save_file(
             echodata.vendor,  # TODO: chunking necessary?
             path=output_path,
-            mode='a',
+            mode="a",
             engine=engine,
-            group='Vendor',
-            compression_settings=COMPRESSION_SETTINGS[engine]
-            if compress
-            else None,
+            group="Vendor",
+            compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
         )
 
 
@@ -346,7 +340,8 @@ def _set_convert_params(param_dict):
     The default set of parameters include:
     - Platform group: ``platform_name``, ``platform_type``, ``platform_code_ICES``, ``water_level``
     - Platform/NMEA: ``nmea_gps_sentence``,
-                    for selecting specific NMEA sentences, with default values ['GGA', 'GLL', 'RMC'].
+                     for selecting specific NMEA sentences,
+                     with default values ['GGA', 'GLL', 'RMC'].
     - Top-level group: ``survey_name``
 
     Other parameters will be saved to the top level.
@@ -410,15 +405,11 @@ def _check_file(raw_file, sonar_model, xml_path=None, storage_options={}):
             raise ValueError(f"XML file is required for {sonar_model} raw data")
         else:
             if ".XML" not in Path(xml_path).suffix.upper():
-                raise ValueError(
-                    f"{Path(xml_path).name} is not an XML file"
-                )
+                raise ValueError(f"{Path(xml_path).name} is not an XML file")
 
         xmlmap = fsspec.get_mapper(str(xml_path), **storage_options)
         if not xmlmap.fs.exists(xmlmap.root):
-            raise FileNotFoundError(
-                f"There is no file named {Path(xml_path).name}"
-            )
+            raise FileNotFoundError(f"There is no file named {Path(xml_path).name}")
 
         xml = xml_path
     else:
@@ -429,14 +420,10 @@ def _check_file(raw_file, sonar_model, xml_path=None, storage_options={}):
     fsmap = fsspec.get_mapper(raw_file, **storage_options)
     ext = MODELS[sonar_model]["ext"]
     if not fsmap.fs.exists(fsmap.root):
-        raise FileNotFoundError(
-            f"There is no file named {Path(raw_file).name}"
-        )
+        raise FileNotFoundError(f"There is no file named {Path(raw_file).name}")
 
     if Path(raw_file).suffix.upper() != ext.upper():
-        raise ValueError(
-            f"Expecting a {ext} file but got {raw_file}"
-        )
+        raise ValueError(f"Expecting a {ext} file but got {raw_file}")
 
     return str(raw_file), str(xml)
 
@@ -482,7 +469,7 @@ def open_raw(
         if xml_path is None:
             sonar_model = "EK60"
             warnings.warn(
-                "Current behavior is to default sonar_model='EK60' when no XML file is passed in as argument. "
+                "Current behavior is to default sonar_model='EK60' when no XML file is passed in as argument. "  # noqa
                 "Specifying sonar_model='EK60' will be required in the future, "
                 "since .raw extension is used for many Kongsberg/Simrad sonar systems.",
                 DeprecationWarning,
@@ -491,7 +478,7 @@ def open_raw(
         else:
             sonar_model = "AZFP"
             warnings.warn(
-                "Current behavior is to set sonar_model='AZFP' when an XML file is passed in as argument. "
+                "Current behavior is to set sonar_model='AZFP' when an XML file is passed in as argument. "  # noqa
                 "Specifying sonar_model='AZFP' will be required in the future.",
                 DeprecationWarning,
                 2,
@@ -517,9 +504,7 @@ def open_raw(
         raise TypeError("file must be a string or Path")
 
     # Check file extension and existence
-    file_chk, xml_chk = _check_file(
-        raw_file, sonar_model, xml_path, storage_options
-    )
+    file_chk, xml_chk = _check_file(raw_file, sonar_model, xml_path, storage_options)
 
     # TODO: the if-else below only works for the AZFP vs EK contrast,
     #  but is brittle since it is abusing params by using it implicitly
@@ -541,13 +526,11 @@ def open_raw(
         params=_set_convert_params(convert_params),
     )
     # Set up echodata object
-    echodata = EchoData(
-        source_file=file_chk, xml_path=xml_chk, sonar_model=sonar_model
-    )
+    echodata = EchoData(source_file=file_chk, xml_path=xml_chk, sonar_model=sonar_model)
     # Top-level date_created varies depending on sonar model
     if sonar_model in ["EK60", "EK80"]:
         echodata.top = setgrouper.set_toplevel(
-            sonar_model=sonar_model, date_created=parser.config_datagram['timestamp']
+            sonar_model=sonar_model, date_created=parser.config_datagram["timestamp"]
         )
     else:
         echodata.top = setgrouper.set_toplevel(
