@@ -1,7 +1,7 @@
-from collections import OrderedDict
-from typing import BinaryIO, Iterable, Union, Callable, List, Optional, Any, Dict
-from enum import Enum, unique, auto
 import struct
+from collections import OrderedDict
+from enum import Enum, auto, unique
+from typing import Any, BinaryIO, Callable, Dict, Iterable, List, Optional, Union
 
 import numpy as np
 
@@ -145,11 +145,11 @@ class Field:
     ):
         """
         field_name: Name of the field. If None, the field is parsed but ignored
-        field_entry_size_bytes: Size of each entry within the field, in bytes. 
+        field_entry_size_bytes: Size of each entry within the field, in bytes.
             In most cases, the entry is the field itself, but sometimes the field
             contains a list of entries.
         field_entry_data_type: Data type of each entry in the field
-        field_shape: Shape of entries within the field. 
+        field_shape: Shape of entries within the field.
             [] (the default) means the entry is the field itself,
             [n] means the field consists of a list of n entries,
             [n, m] means the field consists of a two dimensional array with
@@ -211,7 +211,7 @@ class ParseAd2cp(ParseBase):
     def __init__(
         self,
         *args,
-        burst_average_data_record_version: BurstAverageDataRecordVersion = BurstAverageDataRecordVersion.VERSION3,
+        burst_average_data_record_version: BurstAverageDataRecordVersion = BurstAverageDataRecordVersion.VERSION3,  # noqa
         params,
         **kwargs,
     ):
@@ -299,17 +299,14 @@ class ParseAd2cp(ParseBase):
 
     def get_pulse_compressed(self):
         for i in range(1, 3 + 1):
-            if (
-                "GETECHO" in self.config
-                and self.config["GETECHO"][f"PULSECOMP{i}"] > 0
-            ):
+            if "GETECHO" in self.config and self.config["GETECHO"][f"PULSECOMP{i}"] > 0:
                 return i
         return 0
 
 
 class Ad2cpDataPacket:
     """
-    Represents a single data packet. Each data packet consists of a header data record followed by a 
+    Represents a single data packet. Each data packet consists of a header data record followed by a
     """
 
     def __init__(
@@ -433,7 +430,10 @@ class Ad2cpDataPacket:
         elif self.data_exclude["id"] in (0x17, 0x1B):  # bottom track
             self.data_record_type = DataRecordType.BOTTOM_TRACK
         elif self.data_exclude["id"] in (0x23, 0x24):  # echosounder raw
-            if self.parser.get_pulse_compressed() > 0 and len(self.parser.echosounder_raw_transmit_packets) == 0:
+            if (
+                self.parser.get_pulse_compressed() > 0
+                and len(self.parser.echosounder_raw_transmit_packets) == 0
+            ):
                 # first echosounder raw packet is the transmit packet
                 # if pulse compression is enabled
                 self.data_record_type = DataRecordType.ECHOSOUNDER_RAW_TRANSMIT
@@ -469,7 +469,7 @@ class Ad2cpDataPacket:
         expected_checksum = self.data_exclude["data_record_checksum"]
         assert (
             calculated_checksum == expected_checksum
-        ), f"invalid data record checksum: found {calculated_checksum}, expected {expected_checksum}"
+        ), f"invalid data record checksum: found {calculated_checksum}, expected {expected_checksum}"  # noqa
 
     def _read_data(self, f: BinaryIO, data_format: "HeaderOrDataRecordFormat") -> bytes:
         """
@@ -519,7 +519,8 @@ class Ad2cpDataPacket:
                 # reshape the list of entries into the correct shape
                 parsed_field = np.reshape(parsed_field_entries, field_shape)
             # we cannot check for this before reading because some fields are placeholder fields
-            # which, if not read in the correct order with other fields, will offset the rest of the data
+            # which, if not read in the correct order with other fields,
+            # will offset the rest of the data
             if field_name is not None:
                 self.data[field_name] = parsed_field
                 self._postprocess(field_name)
@@ -566,9 +567,9 @@ class Ad2cpDataPacket:
             (see https://man7.org/linux/man-pages/man2/read.2.html#RETURN_VALUE,
             note "It is not an error if this number is smaller than the number of bytes requested")
             (see https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/read?view=msvc-160#return-value,
-            note "_read returns the number of bytes read, 
+            note "_read returns the number of bytes read,
                 which might be less than buffer_size...if the file was opened in text mode")
-        """
+        """  # noqa
 
         all_bytes_read = bytes()
         if total_num_bytes_to_read <= 0:
@@ -597,7 +598,7 @@ class Ad2cpDataPacket:
             "data_record_checksum",
             "header_checksum",
             "version",
-            "offset_of_data"
+            "offset_of_data",
         ):
             self.data_exclude[field_name] = self.data[field_name]
             del self.data[field_name]
@@ -731,8 +732,10 @@ class Ad2cpDataPacket:
             elif field_name == "ambiguity_velocity_or_echosounder_frequency":
                 if self.data["echosounder_data_included"]:
                     # This is specified as "echo sounder frequency", but the description technically
-                    # says "number of echo sounder cells". It is probably the frequency and not the number of cells
-                    # because the number of cells already replaces the data in "num_beams_and_coordinate_system_and_num_cells"
+                    # says "number of echo sounder cells".
+                    # It is probably the frequency and not the number of cells
+                    # because the number of cells already replaces the data in
+                    # "num_beams_and_coordinate_system_and_num_cells"
                     # when an echo sounder is present
                     self.data["echosounder_frequency"] = self.data[
                         "ambiguity_velocity_or_echosounder_frequency"
@@ -744,7 +747,8 @@ class Ad2cpDataPacket:
             elif field_name == "velocity_scaling":
                 if not self.data["echosounder_data_included"]:
                     # The unit conversion for ambiguity velocity is done here because it
-                    # requires the velocity_scaling, which is not known when ambiguity velocity field is parsed
+                    # requires the velocity_scaling, which is not known
+                    # when ambiguity velocity field is parsed
                     self.data["ambiguity_velocity"] = self.data[
                         "ambiguity_velocity"
                     ] * (10 ** self.data["velocity_scaling"])
@@ -836,7 +840,8 @@ class Ad2cpDataPacket:
                 self.data["beam4"] = 0
             elif field_name == "velocity_scaling":
                 # The unit conversion for ambiguity velocity is done here because it
-                # requires the velocity_scaling, which is not known when ambiguity velocity field is parsed
+                # requires the velocity_scaling,
+                # which is not known when ambiguity velocity field is parsed
                 self.data["ambiguity_velocity"] = self.data["ambiguity_velocity"] * (
                     10 ** self.data["velocity_scaling"]
                 )
@@ -944,7 +949,8 @@ class HeaderOrDataRecordFormats:
                 UNSIGNED_INTEGER,
             ),
             # F("data_record_size", lambda packet: 4 if packet.data_exclude["id"] in (
-            #     0x23, 0x24) else 2, lambda packet: UNSIGNED_LONG if packet.data_exclude["id"] in (0x23, 0x24) else UNSIGNED_INTEGER),
+            #     0x23, 0x24) else 2, lambda packet: UNSIGNED_LONG if packet.data_exclude["id"]
+            #     in (0x23, 0x24) else UNSIGNED_INTEGER),
             F("data_record_checksum", 2, UNSIGNED_INTEGER),
             F("header_checksum", 2, UNSIGNED_INTEGER),
         ]
@@ -1088,7 +1094,8 @@ class HeaderOrDataRecordFormats:
             #         Dimension.TIME, Dimension.BEAM, range_bin(data_record_type)],
             #     field_unit_conversion=lambda packet, x: x *
             #     (10 ** packet.data["velocity_scaling"]),
-            #     field_exists_predicate=lambda packet: packet.is_other() and packet.data["velocity_data_included"]
+            #     field_exists_predicate=lambda packet: packet.is_other()
+            #     and packet.data["velocity_data_included"]
             # ),
             F(  # used when burst
                 "velocity_data_burst",
@@ -1156,7 +1163,8 @@ class HeaderOrDataRecordFormats:
             #     field_dimensions=lambda data_record_type: [
             #         Dimension.TIME, Dimension.BEAM, range_bin(data_record_type)],
             #     field_unit_conversion=lambda packet, x: x / 2,
-            #     field_exists_predicate=lambda packet: not packet.is_burst() and not packet.is_average() and packet.data["amplitude_data_included"]
+            #     field_exists_predicate=lambda packet: not packet.is_burst()
+            #     and not packet.is_average() and packet.data["amplitude_data_included"]
             # ),
             F(
                 "amplitude_data_burst",
@@ -1220,7 +1228,8 @@ class HeaderOrDataRecordFormats:
             #         packet.data.get("num_beams", 0), packet.data.get("num_cells", 0)],
             #     field_dimensions=lambda data_record_type: [
             #         Dimension.TIME, Dimension.BEAM, range_bin(data_record_type)],
-            #     field_exists_predicate=lambda packet: not packet.is_burst() and not packet.is_average() and packet.data["correlation_data_included"]
+            #     field_exists_predicate=lambda packet: not packet.is_burst()
+            #         and not packet.is_average() and packet.data["correlation_data_included"]
             # ),
             F(
                 "correlation_data_burst",
@@ -1413,7 +1422,8 @@ class HeaderOrDataRecordFormats:
             #         Dimension.TIME, Dimension.BEAM, range_bin(data_record_type)],
             #     field_unit_conversion=lambda packet, x: x * \
             #     (10 ** packet.data["velocity_scaling"]),
-            #     field_exists_predicate=lambda packet: not packet.is_burst() and not packet.is_average() and packet.data["velocity_data_included"]
+            #     field_exists_predicate=lambda packet: not packet.is_burst()
+            #     and not packet.is_average() and packet.data["velocity_data_included"]
             # ),
             F(
                 "velocity_data_burst",
@@ -2045,8 +2055,10 @@ class HeaderOrDataRecordFormats:
                 field_dimensions=[Dimension.TIME, Dimension.SAMPLE],
                 field_exists_predicate=lambda packet: packet.is_echosounder_raw(),
             ),
-            # These next 2 fields are included so that the dimensions for this field can be determined
-            # based on the field name ("echosounder_raw_samples" will be deleted later and dimensions are looked up
+            # These next 2 fields are included so that the dimensions
+            # for this field can be determined
+            # based on the field name ("echosounder_raw_samples" will be deleted later
+            # and dimensions are looked up
             # by "echosounder_raw_samples_r" and "echosounder_raw_samples_i")
             F(
                 "echosounder_raw_samples_r",
@@ -2070,8 +2082,10 @@ class HeaderOrDataRecordFormats:
                 field_dimensions=[Dimension.TIME, Dimension.SAMPLE_TRANSMIT],
                 field_exists_predicate=lambda packet: packet.is_echosounder_raw_transmit(),
             ),
-            # These next 2 fields are included so that the dimensions for this field can be determined
-            # based on the field name ("echosounder_raw_transmit_samples" will be deleted later and dimensions are looked up
+            # These next 2 fields are included so that the dimensions
+            # for this field can be determined
+            # based on the field name ("echosounder_raw_transmit_samples"
+            # will be deleted later and dimensions are looked up
             # by "echosounder_raw_transmit_samples_r" and "echosounder_raw_transmit_samples_i")
             F(
                 "echosounder_raw_transmit_samples_r",
